%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% getPT_2incl
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% References:
%   Mathematical and Computational Methods in Photonics and Phononics
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Hyeonbae Kang,
%   Matias Ruiz, Sanghyeon Yu, Hai Zhang
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function PT = getPT_2incl(D1,D2,lambda) 


%% Solving integral equation
nbPoints = D1.nbPoints;
Ks1 = KDstar(D1);
Ks2 = KDstar(D2);

As11 = lambda*eye(nbPoints) - Ks1;
As22 = lambda*eye(nbPoints) - Ks2;
As12 = - dndS(D1,D2);
As21 = - dndS(D2,D1);

As=[As11 As12 ; As21 As22];

phi1 = As\([D1.normal(1,:) D2.normal(1,:)])';
phi2 = As\([D1.normal(2,:) D2.normal(2,:)])';

phi1_D1=phi1(1:nbPoints);
phi1_D2=phi1(nbPoints+1:2*nbPoints);
phi2_D1=phi2(1:nbPoints);
phi2_D2=phi2(nbPoints+1:2*nbPoints);

%% Calulate PT
M = zeros(2,2);

M(1,1) = (D1.points(1,:).*phi1_D1')*D1.sigma' + (D2.points(1,:).*phi1_D2')*D2.sigma';
M(1,2) = (D1.points(2,:).*phi1_D1')*D1.sigma' + (D2.points(2,:).*phi1_D2')*D2.sigma';
M(2,1) = (D1.points(1,:).*phi2_D1')*D1.sigma' + (D2.points(1,:).*phi2_D2')*D2.sigma';
M(2,2) = (D1.points(2,:).*phi2_D1')*D1.sigma' + (D2.points(2,:).*phi2_D2')*D2.sigma';

PT=M;
